===============================
Module Documentation
===============================

Module contents
---------------

.. automodule:: pyedgeconnect
   :members:
   :special-members: __init__
   :undoc-members:
   :show-inheritance:
   :member-order: bysource
